@@ -15,11 +15,11 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/build/3dslicer/src/build/python-install/bin',
  'BINLIBDEST': '/build/3dslicer/src/build/python-install/lib/python3.12',
  'BLDLIBRARY': 'libpython3.12.a',
- 'BLDSHARED': '/usr/bin/gcc-14  -pthread -shared',
+ 'BLDSHARED': '/usr/bin/clang  -pthread -shared',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-unknown-linux-gnu',
- 'CC': '/usr/bin/gcc-14  -pthread',
+ 'CC': '/usr/bin/clang  -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
@@ -27,8 +27,7 @@ build_time_vars = {'ABIFLAGS': '',
            '-fcf-protection         -fno-omit-frame-pointer '
            '-mno-omit-leaf-frame-pointer -g '
            '-ffile-prefix-map=/build/3dslicer/src=/usr/src/debug/3dslicer '
-           '-flto=auto    -std=c11 -Wall -Wstrict-prototypes '
-           '-fno-strict-aliasing -fwrapv',
+           '-flto=auto    -Wall',
  'CFLAGSFORSHARED': '',
  'CONFIGFILES': 'configure configure.in acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
@@ -37,7 +36,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEPY': '/build/3dslicer/src/build/python-install/include/python3.12',
  'COREPYTHONPATH': ':plat-linux:lib-tk:lib-old',
  'CPPFLAGS': '',
- 'CXX': '/usr/bin/g++-14  -pthread',
+ 'CXX': '/usr/bin/clang++  -pthread',
  'DESTLIB': '/build/3dslicer/src/build/python-install/lib/python3.12',
  'DESTPATH': '',
  'DESTSHARED': '/build/3dslicer/src/build/python-install/lib/python3.12/lib-dynload',
@@ -348,7 +347,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
  'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
- 'HAVE_OPENAT': 1,
+ 'HAVE_OPENAT': 0,
  'HAVE_OPENDIR': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_OSX105_SDK': 0,
@@ -470,7 +469,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STDINT_H': 1,
  'HAVE_STDIO_H': 1,
  'HAVE_STDLIB_H': 1,
- 'HAVE_STD_ATOMIC': 1,
+ 'HAVE_STD_ATOMIC': 0,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
@@ -603,12 +602,12 @@ build_time_vars = {'ABIFLAGS': '',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
  'INSTSONAME': 'libpython3.12.a',
- 'LDCXXSHARED': '/usr/bin/g++-14  -pthread -shared',
+ 'LDCXXSHARED': '/usr/bin/clang++  -pthread -shared',
  'LDFLAGS': '',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.12.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': '/usr/bin/gcc-14  -pthread -shared',
+ 'LDSHARED': '/usr/bin/clang  -pthread -shared',
  'LDVERSION': '3.12',
  'LIBC': '',
  'LIBDEST': '/build/3dslicer/src/build/python-install/lib/python3.12',
@@ -620,7 +619,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBPL': '/build/3dslicer/src/build/python-install/lib/python3.12/config',
  'LIBRARY': 'libpython3.12.a',
  'LIBS': '-lpthread -ldl  -lutil',
- 'LINKCC': '/usr/bin/gcc-14  -pthread',
+ 'LINKCC': '/usr/bin/clang  -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LN': 'ln',
  'LOCALMODLIBS': '',
@@ -629,7 +628,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MACHDEPPATH': ':plat-linux',
  'MACHDESTLIB': '/build/3dslicer/src/build/python-install/lib/python3.12',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': '/usr/bin/gcc-14  -pthread',
+ 'MAINCC': '/usr/bin/clang  -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': '/build/3dslicer/src/build/Python-3.12.10/Modules/makesetup',
@@ -643,8 +642,7 @@ build_time_vars = {'ABIFLAGS': '',
         '-fstack-clash-protection -fcf-protection         '
         '-fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g '
         '-ffile-prefix-map=/build/3dslicer/src=/usr/src/debug/3dslicer '
-        '-flto=auto    -std=c11 -Wall -Wstrict-prototypes -fno-strict-aliasing '
-        '-fwrapv -DNDEBUG',
+        '-flto=auto    -Wall -DNDEBUG',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -671,8 +669,7 @@ build_time_vars = {'ABIFLAGS': '',
               '-fcf-protection         -fno-omit-frame-pointer '
               '-mno-omit-leaf-frame-pointer -g '
               '-ffile-prefix-map=/build/3dslicer/src=/usr/src/debug/3dslicer '
-              '-flto=auto    -std=c11 -Wall -Wstrict-prototypes '
-              '-fno-strict-aliasing -fwrapv -DPy_BUILD_CORE',
+              '-flto=auto    -Wall -DPy_BUILD_CORE',
  'PY_COERCE_C_LOCALE': 1,
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
